@@ -103,7 +103,9 @@ fn get_real_market_type(exchange: &str, market_type: MarketType, symbol: &str) -
 }
 
 fn is_blocked_market(market_type: MarketType) -> bool {
-    market_type == MarketType::QuantoFuture || market_type == MarketType::QuantoSwap
+    market_type == MarketType::QuantoFuture
+        || market_type == MarketType::QuantoSwap
+        || market_type == MarketType::EuropeanOption // TODO: need to figure out how to parse option data
 }
 
 /// Split a file by symbol and write to multiple files.
